==> haskell-hslua-module-system-0.2.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-9leuyPuUz743azeeYMxc8E
key: hslua-module-system-0.2.1-9leuyPuUz743azeeYMxc8E
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: 53cdecd3919cdfb78edc1bef1a697aea
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-9leuyPuUz743azeeYMxc8E
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    hslua-1.0.3.2-9XdBa9n2D5gDaNt3JZ5IEq
    temporary-1.3-F6xRo1rNLbCADrAA6svjLo
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-0.2.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-system
version: 0.2.1
id: hslua-module-system-0.2.1-Fxx9WPHFZIKKCSg1YqTr4l
key: hslua-module-system-0.2.1-Fxx9WPHFZIKKCSg1YqTr4l
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-system
synopsis: Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and functionality
    to Lua scripts via Haskell'\''s `System` module.
    .
    Intended usage for this package is to preload it by adding
    the loader function to `package.preload`. Note that the
    Lua `package` library must have already been loaded before
    the loader can be added.
category: Foreign
abi: 586b638edaae29449aef7964093227c1
exposed: True
exposed-modules:
    Foreign.Lua.Module.System
hidden-modules: Foreign.Lua.Module.SystemUtils
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslua-module-system-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslua-module-system-0.2.1
hs-libraries: HShslua-module-system-0.2.1-Fxx9WPHFZIKKCSg1YqTr4l
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    hslua-1.0.3.2-5h9nVB07WjnrmFtle4MfG
    temporary-1.3-F6xRo1rNLbCADrAA6svjLo
haddock-interfaces: /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
